gchecky.tools.decoder

Package gchecky :: Module tools :: Class decoder |
[hide private]
[frames] | no frames]

# Class decoder

source code

Instance Methods | [hide private]
deserialize(self, node) | source code
_reduce_list(self, l) | source code
_reduce_diction(self, diction) | source code
_decode_into_dict(self, node) | source code
_add_to_dict(self, diction, key, data) | source code

Class Methods | [hide private]
_decode_tag(clazz, tag) | source code
_decode_string(clazz, str) | source code